#############
API reference
#############


.. automodule:: festim.boundary_conditions
    :members:
    :show-inheritance:

.. automodule:: festim.exports
    :members:
    :show-inheritance:

.. automodule:: festim.mesh
    :members:
    :show-inheritance:

.. automodule:: festim.subdomain
    :members:
    :show-inheritance:

.. automodule:: festim.advection
    :members:
    :show-inheritance:

.. automodule:: festim.coupled_heat_hydrogen_problem
    :members:
    :show-inheritance:

.. automodule:: festim.heat_transfer_problem
    :members:
    :show-inheritance:

.. automodule:: festim.helpers
    :members:
    :show-inheritance:

.. automodule:: festim.hydrogen_transport_problem
    :members:
    :show-inheritance:

.. automodule:: festim.initial_condition
    :members:
    :show-inheritance:

.. automodule:: festim.material
    :members:
    :show-inheritance:

.. automodule:: festim.problem
    :members:
    :show-inheritance:

.. automodule:: festim.reaction
    :members:
    :show-inheritance:

.. automodule:: festim.settings
    :members:
    :show-inheritance:

.. automodule:: festim.source
    :members:
    :show-inheritance:

.. automodule:: festim.species
    :members:
    :show-inheritance:

.. automodule:: festim.stepsize
    :members:
    :show-inheritance:

.. automodule:: festim.trap
    :members:
    :show-inheritance:
